# ByeStore

An App Store for all (except iOS, you know why)

[![Documentation Status](https://readthedocs.org/projects/byestore/badge/?version=latest)](https://byestore.readthedocs.io/en/latest/?badge=latest) [![Discord](https://img.shields.io/discord/827083552155238460?color=7289DA&label=Official%20Chats%20%5Bwith%20ByeStore%20channels%5D&logo=discord&logoColor=white)](https://discord.gg/XvHXmeuzdg)

Visit the store [online](//apps.byemc.xyz/)

[Download it!](//apps.byemc.xyz/byemc/byestore/)

NOTE: LINKS ARE **NOT** OPERATIONAL AT THIS MOMENT.
